@@ -11,10 +11,19 @@ from git import Repo,GitCommandError
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 log=logging.getLogger(__name__)
+log.setLevel(logging.INFO)
+formatter = logging.Formatter(
+    fmt="%(asctime)s | %(levelname)s | %(name)s | %(filename)s:%(lineno)d | %(message)s",
+    datefmt="%Y-%m-%d %H:%M:%S"
+)
+console_handler = logging.StreamHandler()
+console_handler.setFormatter(formatter)
+log.addHandler(console_handler)
 
 
 class ExecResult:
     def __init__(self,stdout,stderr,exit_code):
+        log.info(f"exit_code:{exit_code},stdout: {stdout},stderr:{stderr}")
         self.stdout=stdout
         self.stderr=stderr
         self.exit_code=exit_code
@@ -90,19 +99,8 @@ class Server():
         return shutil.os.path.exists(path) and shutil.os.path.isdir(path)
 
     def exec_command(self, command: Union[str, List[str]]) -> ExecResult:
-        """
-        执行系统命令并返回执行结果
-
-        参数:
-            command: 要执行的命令，可以是字符串或字符串列表
-                     列表形式更安全，避免shell注入风险
-
-        返回:
-            ExecResult对象，包含命令执行的stdout、stderr和exit_code
-        """
+        log.info(f"执行命令: {command}")
         try:
-            # 执行命令，捕获 stdout 和 stderr
-            # 使用shell=True时command可为字符串，否则应为列表
             shell = isinstance(command, str)
             result = subprocess.run(
                 command,
@@ -111,7 +109,7 @@ class Server():
                 text=True,
                 shell=shell,
                 encoding='utf-8',
-                errors='replace'  # 处理编码错误
+                errors='replace'
             )
             returncode=result.returncode
             stderr=result.stderr
@@ -132,30 +130,9 @@ class Server():
             )
 
     def git_clone(self, repo_url: str, branch: str, dest_path: str) -> bool:
-        """
-        克隆指定Git仓库的指定分支到目标路径
-
-        功能说明：
-            1. 检查目标路径是否已存在，避免覆盖现有文件
-            2. 自动创建目标路径的父目录（如果不存在）
-            3. 克隆指定分支到目标路径并验证结果
-            4. 验证克隆后的仓库分支是否与预期一致
-
-        参数：
-            repo_url: Git仓库的URL地址（例如：https://github.com/example/repo.git）
-            branch: 需要克隆的分支名称（例如：main、dev）
-            dest_path: 本地目标路径，克隆后的仓库将存储在此路径下
-
-        返回：
-            bool: 克隆成功且验证通过返回True，否则返回False
-
-        异常处理：
-            捕获Git命令执行异常和其他通用异常，并记录警告日志
-        """
+        log.info(f"开始克隆仓库: {repo_url} branch {branch} 到 {dest_path}")
         try:
-            # 检查目标路径是否已存在
             if os.path.exists(dest_path):
-                # 检查是否为已存在的Git仓库
                 git_dir = os.path.join(dest_path, '.git')
                 if os.path.isdir(git_dir):
                     log.warning(f"目标路径 '{dest_path}' 已存在且为Git仓库，无法克隆")
@@ -164,24 +141,20 @@ class Server():
                     log.warning(f"目标路径 '{dest_path}' 已存在但不是Git仓库，无法克隆")
                     return False
 
-            # 确保父目录存在
             parent_dir = os.path.dirname(dest_path)
             if parent_dir and not os.path.exists(parent_dir):
                 os.makedirs(parent_dir, exist_ok=True)
 
-            # 执行克隆操作
             repo = Repo.clone_from(
                 url=repo_url,
                 to_path=dest_path,
                 branch=branch
             )
 
-            # 验证仓库是否为裸仓库（异常情况）
             if repo.bare:
                 log.warning(f"克隆失败，创建了裸仓库: {dest_path}")
                 return False
 
-            # 验证当前分支是否与预期一致
             current_branch = repo.active_branch.name
             if current_branch != branch:
                 log.warning(
@@ -189,13 +162,14 @@ class Server():
                     f"实际分支: {current_branch}, 预期分支: {branch}"
                 )
                 return False
+            log.info(f"克隆成功: {dest_path}")
             return True
 
         except GitCommandError as e:
             log.warning(f"Git命令执行失败: {str(e)}")
             return False
         except Exception as e:
-            log.warn(f"克隆过程中发生未知错误: {str(e)}")
+            log.warning(f"克隆过程中发生未知错误: {str(e)}")
             return False
 
     def find_all_file(
@@ -209,77 +183,46 @@ class Server():
             absolute_path: bool = True,
             only_file_name: bool = False
     ) -> List[str]:
-        """
-        查找指定目录下符合条件的所有文件名称或路径
-
-        参数:
-            root_dir: 查找的根目录
-            suffix: 文件名后缀过滤（如".txt"或"txt"），为None则不过滤
-            with_suffix: 是否包含文件后缀（仅在返回文件名时生效）
-            recursive: 是否递归查找子目录
-            exclude_dirs: 要排除的目录名称列表（支持全称匹配）
-            exclude_files: 要排除的文件名称列表（支持全称匹配）
-            absolute_path: 是否返回绝对路径（仅在不返回纯文件名时生效）
-            only_file_name: 是否只返回文件名（不包含路径）
-
-        返回:
-            符合条件的文件路径或名称列表（去重后按查找顺序排列）
-        """
-        # 处理排除列表（转为集合提高查找效率）
+        log.info(f"开始查找文件: root_dir:{root_dir},suffix:{suffix},with_suffix:{with_suffix},recursive:{recursive},exclude_dirs:{exclude_dirs},exclude_files:{exclude_files},absolute_path:{absolute_path},only_file_name:{only_file_name}.")
         exclude_dirs_set: Set[str] = set(exclude_dirs) if exclude_dirs else set()
         exclude_files_set: Set[str] = set(exclude_files) if exclude_files else set()
 
-        # 验证根目录有效性
         root_dir = os.path.abspath(root_dir)
         if not os.path.isdir(root_dir):
-            raise NotADirectoryError(f"根目录不存在或不是目录: {root_dir}")
+            log.warning(f"根目录不存在或不是目录: {root_dir}")
+            return None
 
-        # 统一处理后缀格式（确保以点开头）
         if suffix is not None and not suffix.startswith('.'):
             suffix = f'.{suffix}'
 
         result: List[str] = []
-        seen: Set[str] = set()  # 用于去重
+        seen: Set[str] = set()
 
-        # 遍历目录
         for dirpath, dirnames, filenames in os.walk(root_dir):
-            # 排除指定目录（修改dirnames影响os.walk递归行为）
             dirnames[:] = [d for d in dirnames if d not in exclude_dirs_set]
-
             for filename in filenames:
-                # 排除指定文件
                 if filename in exclude_files_set:
+                    log.warning(f"文件被排除: {filename}")
                     continue
-
-                # 后缀过滤
                 if suffix is not None and not filename.endswith(suffix):
+                    log.warning(f"文件后缀不匹配: {filename}")
                     continue
-
-                # 处理文件名（是否包含后缀）
                 processed_name = filename if with_suffix else os.path.splitext(filename)[0]
-
-                # 根据参数决定返回内容
                 if only_file_name:
-                    # 只返回文件名（去重）
                     if processed_name not in seen:
                         seen.add(processed_name)
                         result.append(processed_name)
                 else:
-                    # 构建文件路径
                     full_path = os.path.join(dirpath, filename)
-                    # 处理路径格式（绝对/相对）
                     if absolute_path:
                         display_path = os.path.abspath(full_path)
                     else:
                         display_path = os.path.relpath(full_path, root_dir)
 
-                    # 处理路径中的文件名是否包含后缀
                     if not with_suffix:
-                        # 只移除文件名部分的后缀，保留路径结构
                         dir_part, file_part = os.path.split(display_path)
                         display_path = os.path.join(dir_part, os.path.splitext(file_part)[0])
 
-                    # 路径去重
                     if display_path not in seen:
                         seen.add(display_path)
                         result.append(display_path)
@@ -292,35 +235,22 @@ class Server():
                      f"根目录: {root_dir}, 后缀: {suffix}, 递归: {recursive}, "
                      f"排除目录: {exclude_dirs}, 排除文件: {exclude_files}, "
                      f"绝对路径: {absolute_path}, 纯文件名: {only_file_name}")
-
+        log.info(f"已找到文件 - {result}")
         return result
 
     def read_json(self, file_path: str) -> Optional[Any]:
-        """
-        读取并解析JSON文件内容
-
-        参数:
-            file_path: JSON文件的路径（相对路径或绝对路径）
-
-        返回:
-            解析后的JSON数据（字典、列表等），如果发生错误则返回None
-        """
-        # 检查文件是否存在
+        log.info(f"正在读取JSON文件 - {file_path}")
         if not os.path.exists(file_path):
             log.warning(f"错误: 文件不存在 - {file_path}")
             return None
-
-        # 检查是否为文件
         if not os.path.isfile(file_path):
             log.warning(f"错误: 不是有效的文件 - {file_path}")
             return None
-
         try:
-            # 打开并读取JSON文件
             with open(file_path, 'r', encoding='utf-8') as file:
                 try:
-                    # 解析JSON数据
                     json_data = json.load(file)
+                    log.info(f"成功读取JSON文件 - {file_path}, data is {json_data}")
                     return json_data
                 except json.JSONDecodeError as e:
                     log.warning("错误: JSON解析失败 - {str(e)}，文件: {file_path}")
@@ -328,7 +258,6 @@ class Server():
                 except Exception as e:
                     log.warning(f"错误: 读取文件内容时发生意外 - {str(e)}，文件: {file_path}")
                     return None
-
         except PermissionError:
             log.warning(f"错误: 没有权限打开文件 - {file_path}")
             return None
@@ -337,27 +266,16 @@ class Server():
             return None
 
     def get_abs_path(self, file_name: str, dest_dir: str) -> Optional[str]:
-        """
-        在指定目录下查找指定文件名的文件，并返回第一个找到的文件的绝对路径
-
-        参数:
-            file_name: 要查找的文件名（包含后缀）
-            dest_dir: 要搜索的目标目录
-
-        返回:
-            找到的文件的绝对路径；如果未找到或发生错误则返回None
-        """
-        # 验证目标目录是否存在且是有效目录
+        log.info(f"正在获取绝对路径 - 文件名: {file_name}，目标目录: {dest_dir}")
         if not os.path.isdir(dest_dir):
+            log.warning(f"错误: 目标目录不存在或不是目录 - {dest_dir}")
             return None
 
-        # 遍历目标目录下的所有文件和子目录
         for root, _, files in os.walk(dest_dir):
-            # 检查当前目录下是否存在目标文件
             if file_name in files:
-                # 构建并返回绝对路径
-                return os.path.abspath(os.path.join(root, file_name))
+                abs_path=os.path.abspath(os.path.join(root, file_name))
+                log.info(f"成功获取绝对路径 - 文件名: {file_name}，绝对路径: {abs_path}")
+                return abs_path
 
-        # 遍历结束仍未找到文件
         log.warning(f"未找到文件 - {file_name}，目录: {dest_dir}")
         return None
\ No newline at end of file
